@@ -2,6 +2,7 @@ from assertions.assertions import assert_
 from assertions.solutions.common import assert_all, assert_any, assert_lte, assert_truth
 from assertions.solutions.models import assert_model_equal
 from assertions.solutions.response import assert_attr, assert_json, assert_response_status
+from assertions.validators import validate_json
 
 __all__ = [
     'assert_',
@@ -12,5 +13,6 @@ __all__ = [
     'assert_attr',
     'assert_json',
     'assert_response_status',
-    'assert_model_equal'
+    'assert_model_equal',
+    'validate_json'
 ]
